Crate limestone_client

Crate limestone_client 

Modules

errors
This code was AUTOGENERATED using the kinobi library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun kinobi to update it.
hash
instructions
This code was AUTOGENERATED using the kinobi library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun kinobi to update it.
programs
This code was AUTOGENERATED using the kinobi library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun kinobi to update it.

Constants

ID
limestone program ID.

Functions

find_pda
Return the PDA and bump seed for the given from and slot derivation.
find_pda_with_seed
Return the PDA and bump seed for the given from, slot, and base derivation.