This code was AUTOGENERATED using the kinobi library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun kinobi to update it.
Constants
- LIMESTONE_
ID limestoneprogram ID.
This code was AUTOGENERATED using the kinobi library. Please DO NOT EDIT THIS FILE, instead use visitors to add features, then rerun kinobi to update it.
limestone program ID.